Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
bnf_parser_messages.ml1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38(* This file was auto-generated based on "bnf_parser.messages". *) (* Please note that the function [message] can raise [Not_found]. *) let message = fun s -> match s with | 26 -> "Invalid\tright-hand side of a rule.\nExample of a valid rule: <start> ::= <foo> | <bar> ;\n" | 21 -> "Invalid repetition syntax. Did you forget to close a brace?\nExamples of valid rules:\n <foo> ::= <bar>{1,4}\n <baz> ::= <foo>{5}\n" | 20 -> "Invalid right-hand side of a rule.\nExample of a valid rule: <start> ::= <foo> | <bar> ;\n" | 16 -> "Invalid repetition syntax. Should be \"{num}\" or \"{min, max}\".\nExamples of valid rules:\n <foo> ::= <bar>{1,4}\n <baz> ::= <foo>{5}\n" | 15 -> "Invalid repetition syntax. Should be \"{num}\" or \"{min, max}\".\nExamples of valid rules:\n <foo> ::= <bar>{1,4}\n <baz> ::= <foo>{5}\n" | 13 -> "Invalid repetition syntax. Should be \"{num}\" or \"{min, max}\".\nExamples of valid rules:\n <foo> ::= <bar>{1,4}\n <baz> ::= <foo>{5}\n" | 12 -> "Invalid repetition syntax. Should be \"{num}\" or \"{min, max}\".\nExamples of valid rules:\n <foo> ::= <bar>{1,4}\n <baz> ::= <foo>{5}\n" | 11 -> "Invalid right-hand side of a rule.\nExample of a valid rule: <foo> ::= \"foo\" ;\n" | 9 -> "Invalid repetition syntax. Did you forget an opening brace?\nExamples of valid rules:\n <foo> ::= <bar>{1,4}\n <baz> ::= <foo>{5}\n" | 8 -> "Invalid right-hand side of a rule.\nExample of a valid rule: <foo> ::= \"foo\" ;\n" | 6 -> "Invalid right-hand side of a rule.\nExample of a valid rule: <foo> ::= \"foo\" ;\n" | 5 -> "Left-hand side of a rule must be a single symbol identifier followed by \"::=\".\nIn your rule, a symbol identifier is followed by a string or the right-hand side is empty.\nExample of a valid rule: <foo> ::= \"foo\" ;\n" | 3 -> "Sticky flag (~)\tmust be attached to a symbol.\n" | 0 -> "Sticky flag (~) must be attached to a symbol.\n" | _ -> raise Not_found